
%Find the concentration of various greenhouse gases 
%   in the atmosphere.  Integrate and solve for the 
%   differential equations for CO2 and CH4.  

%two vectors representing the concentration of 
%  greenhouses gases from main model
%
%solve DiffEQ
%   create co2_con and ch4_con arrays
%   conversion to be done in ppmTORad
%  
% Initial condition
  y0=zeros(1,7);
  y1=zeros(1,3);
%
% Independent variable for ODE integration
% base year of model
  t0=1850;
% final year of the model (2200 instead of 2100 
% to match the couter)
  tf=2200;
% define range of time to be output by the model
  tout=[t0:10:tf]'; 
% number of iterations to be made by simulation
  nout=26;
% counter of model call, used for debugging
  ncall=0;
%
% ODE itegration
  reltol=1.0e-06; abstol=1.0e-06;
  options=odeset('RelTol',reltol,'AbsTol',abstol);
  [t,y_c]=ode45 (@carbon,tout,y0,options);
  [t,y_m]=ode45 (@methane,tout,y1,options);
%
%display output
%
    fprintf('\n Year\t CO2_ppm \t    CH4_ppb \t   r1') 
    % begins for loop, counter "it"
    for it=1:nout
    % set the "present" time in the simulation
    t = t0+10*(it-1);
    % Calculate the emission rate and constant for the carbon model
    [c1,r1]=CO2_rate(t);
%
%   CO2 ppm (in lower atmosphere)
    co2_con(it) = 280*(1+y_c(it,1));
%   
%   CH4 ppb (in lower atmosphere)
    ch4_con(it) = 812.5*(1+y_m(it,1));
%
%   Selected output
    fprintf('\n%5.0f%11.4f%15.4f%10.4f',...
              t,co2_con(it),ch4_con(it),r1);
    end

