% clear memory and screen for new simulation
clear; clc;

%declare global variables for the entire model

%base year: 1850
%year increment: 10 yr
y_base = 1850;
y_inc = 10;

%calcautled concentration
%co2_con - carbon concentration
%ch4_con - methane concentration
%R_sun - incoming sun ray

global co2_con ch4_con R_sun;

%Sun's output (W/m2)
R_sun = 343;

%Earth's surface area
%Only component facing the sun is accounted for
r = 300;
A_earth = 3.1416*r^2;

%call the script GHG to calcaute the greenhouse gas 
%   concentrations. 
GHG; 

%Title for the columns to be displayed

fprintf('\n\n Year \t GHG absorbtion\t  Surface temperature');

for i = 1:26
    %
    %Follow energy flow of the sun's rays:
    %
    %Incident ray reflected by clouds, and incident on earth,
    %   which is then reflected to the sky again.
    E_earth(i) = E_abs(R_sun, i);        
    
    %With gas concentration, find the absorbed radiation 
    %   by these gases
    E_retATM(i) = ppmToRad(co2_con, ch4_con, i);
    
    %Given gas concentration and incident radiation, find the 
    %   surface temperature.
    %Temp_sur(i)=0.329*E_retATM(i)+288.56;
    Temp_sur(i)=0.329*E_retATM(i);
    
    
    %Display the results from the calcualted arrays in the order:
    %  year, radiation calimed by GHG, surface temperature increase from
    %  GHG
    fprintf('\n%5.0f%16.4f%20.4f%10.1f%10.3f%10.3f%10.4f\n',...
              y_base + y_inc*(i-1), E_retATM(i),Temp_sur(i));
end

    %Calcualte the temperture increase difference between 2010 and 2100,
    %the main results of the program run
    fprintf('\n\ntemperture increase from 2010 to 2100:\t');
    fprintf('%10.4f',Temp_sur(26)-Temp_sur(16));
    fprintf('\n\n');

