function power = ppmTOrad( co2, ch4, yr )

%translate the ppm calcualted in methane and CO2 to W/m2 values
%these are all based on equations from 
%IPCC climate change 2001 report

%Original concentration of various gases at the reference year
%Carbon dioxide (ppm)
%Methane (ppb)
%Nitrous Oxide (ppb)
Co = 278;
Mo = 700;
No = 270;

%for carbon dioxide:
%
%Alternative method, not used here
%   F_co2 = 5.35*log(carbon(yr)/Co);
%
F_co2 = 4.841*log(co2(yr)/Co)+0.0906*(sqrt(co2(yr)) - sqrt(Co));

%for methane:
F_ch4 = 0.036*(sqrt(ch4(yr)) - sqrt(Mo)) - ...
    (f(ch4(yr),No) - f(Mo,No));

%Total power retained by the atmosphere from both green house gases
power = F_co2 + F_ch4;

%Auxiliary functions used, defined here for ease of implementation
function num = f(A, B)
num = 0.47*log(1+(2.01E-5)*(A*B)^(0.75)+(5.31E-15)*A*(A*B)^(1.52));

